==> power_reviews-8.x-1.0.tar.gz: power_reviews/src/Form/PowerReviewsConfigureForm.php <==
<?php

namespace Drupal\power_reviews\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Entity\Query\QueryFactory;
Use Drupal\node\Entity\NodeType;

/**
 * Building Power Reviews config form.
 */
class PowerReviewsConfigureForm extends ConfigFormBase {

  /**
   * Node Types Array.
   *
   * @var array
   */
  private $nodeTypes;

  /**
   * Constructs a PowerReviewsConfigureForm object.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeManager $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
    $this->nodeTypes = $this->getNodeTypes();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('entity.query')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'power_reviews_configure_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['power_reviews.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('power_reviews.settings');

    $form['powerreviews_fieldset'] = [
      '#type' => 'fieldset',
      '#title' => 'Power Review API Details',
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];

    $form['powerreviews_fieldset']['power_reviews_api_key'] = [
      '#type' => 'textfield',
      '#title' => 'API Key',
      '#required' => TRUE,
      '#default_value' => $config->get('power_reviews_api_key'),
    ];

    $form['powerreviews_fieldset']['power_reviews_merchant_group_id'] = [
      '#type' => 'textfield',
      '#title' => 'Merchant Group ID',
      '#required' => TRUE,
      '#default_value' => $config->get('power_reviews_merchant_group_id'),
    ];

    $form['powerreviews_fieldset']['power_reviews_merchant_id'] = [
      '#type' => 'textfield',
      '#title' => 'Merchant ID',
      '#required' => TRUE,
      '#default_value' => $config->get('power_reviews_merchant_id'),
    ];

    $form['powerreviews_fieldset']['power_reviews_locale'] = [
      '#type' => 'textfield',
      '#title' => 'Locale',
      '#required' => TRUE,
      '#default_value' => $config->get('power_reviews_locale'),
    ];

    $form['powerreviews_fieldset']['power_reviews_feedless_implementation'] = [
      '#type' => 'radios',
      '#title' => 'Is this a feedless implementation?',
      '#required' => TRUE,
      '#options' => [
        'yes' => 'Yes',
        'no' => 'No',
      ],
      '#default_value' => $config->get('power_reviews_feedless_implementation'),
    ];

    $form['powerreviews_fieldset']['power_reviews_type_of_implementation'] = [
      '#type' => 'radios',
      '#title' => 'Type of implementation',
      '#required' => TRUE,
      '#options' => [
        'page_path' => 'Path based',
        'content_type' => 'Content type based',
      ],
      '#default_value' => $config->get('power_reviews_type_of_implementation'),
    ];

    $form['powerreviews_options_fieldset'] = [
      '#type' => 'fieldset',
      '#title' => 'Power Reviews Options',
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];

    $form['powerreviews_options_fieldset']['power_reviews_page_path'] = [
      '#type' => 'textfield',
      '#title' => 'Page path',
      '#description' => $this->t('Add page path on which power reviews should appear.'),
      '#default_value' => $config->get('power_reviews_page_path'),
      '#states' => [
        'visible' => [
          ':input[name="power_reviews_type_of_implementation"]' => ['value' => 'page_path'],
        ],
      ],
    ];

    $form['powerreviews_options_fieldset']['power_reviews_page_id'] = [
      '#type' => 'textfield',
      '#title' => 'Review page id',
      '#description' => $this->t('Add power reviews page id.'),
      '#default_value' => $config->get('power_reviews_page_id'),
      '#states' => [
        'visible' => [
          ':input[name="power_reviews_type_of_implementation"]' => ['value' => 'page_path'],
        ],
      ],
    ];

    $form['powerreviews_options_fieldset']['power_reviews_applied_content_types'] = [
      '#type' => 'checkboxes',
      '#title' => 'Content type select',
      '#description' => $this->t('Select content types on which power reviews should appear.'),
      '#options' => $this->nodeTypes,
      '#default_value' => $config->get('power_reviews_applied_content_types'),
    ];

    $form['powerreviews_options_fieldset']['power_reviews_applied_reviewsnippet'] = [
      '#type' => 'textfield',
      '#title' => 'Review snippet',
      '#description' => $this->t('Add div ID where review snippet should appear.'),
      '#default_value' => $config->get('power_reviews_applied_reviewsnippet'),
    ];

    $form['powerreviews_options_fieldset']['power_reviews_applied_reviewdisplay'] = [
      '#type' => 'textfield',
      '#title' => 'Review display',
      '#description' => $this->t('Add div ID where review display should appear.'),
      '#default_value' => $config->get('power_reviews_applied_reviewdisplay'),
    ];

    $form['powerreviews_options_fieldset']['power_reviews_custom_header'] = [
      '#type' => 'textarea',
      '#title' => 'Custom header',
      '#description' => $this->t('Enter header to be displayed above reviews.'),
      '#default_value' => $config->get('power_reviews_custom_header'),
    ];

    $form['powerreviews_options_fieldset']['power_reviews_applied_categorysnippet'] = [
      '#type' => 'textfield',
      '#title' => 'Category snippet',
      '#description' => $this->t('Add div ID where review star summary should appear.'),
      '#default_value' => $config->get('power_reviews_applied_categorysnippet'),
      '#states' => [
        'invisible' => [
          ':input[name="power_reviews_type_of_implementation"]' => ['value' => 'page_path'],
        ],
      ],
    ];

    $form['powerreviews_options_fieldset']['power_reviews_category_pages'] = [
      '#type' => 'textarea',
      '#title' => 'Category pages',
      '#description' => $this->t('Specify pages by using their paths on which category snippet should appear. Enter one path per line with leading slash.'),
      '#default_value' => $config->get('power_reviews_category_pages'),
      '#states' => [
        'invisible' => [
          ':input[name="power_reviews_type_of_implementation"]' => ['value' => 'page_path'],
        ],
      ],
    ];

    $form['powerreviews_review_fieldset'] = [
      '#type' => 'fieldset',
      '#title' => 'Write a Review Page',
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_link'] = [
      '#type' => 'textfield',
      '#title' => 'Path to write a review page',
      '#description' => $this->t('Genreates the Review Form page.'),
      '#default_value' => $config->get('power_reviews_write_review_link'),
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_page_title'] = [
      '#type' => 'textfield',
      '#title' => 'Title for write a review page',
      '#description' => $this->t('Title for the review form page.'),
      '#default_value' => $config->get('power_reviews_write_review_page_title'),
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review'] = [
      '#type' => 'textfield',
      '#title' => 'Write a review',
      '#description' => $this->t('Add div ID to show the review form.'),
      '#default_value' => $config->get('power_reviews_write_review'),
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_custom_header'] = [
      '#type' => 'radios',
      '#title' => 'Do you want a custom header?',
      '#description' => $this->t('This header will appear on top section of Write a review page.'),
      '#options' => [
        'yes' => 'Yes',
        'no' => 'No',
      ],
      '#default_value' => $config->get('power_reviews_write_review_custom_header'),
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_custom_header_title'] = [
      '#type' => 'textfield',
      '#title' => 'Header title',
      '#description' => $this->t('Enter title for header.'),
      '#default_value' => $config->get('power_reviews_write_review_custom_header_title'),
      '#states' => [
        'visible' => [
          ':input[name="power_reviews_write_review_custom_header"]' => ['value' => 'yes'],
        ],
      ],
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_custom_header_body'] = [
      '#type' => 'textarea',
      '#title' => 'Header body',
      '#description' => $this->t('Enter body for header.'),
      '#default_value' => $config->get('power_reviews_write_review_custom_header_body'),
      '#states' => [
        'visible' => [
          ':input[name="power_reviews_write_review_custom_header"]' => ['value' => 'yes'],
        ],
      ],
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = ['#type' => 'submit', '#value' => 'Save configuration'];

    if (!empty($_POST) && $form_state->getErrors()) {
      $this->messenger()->addError($this->t('The settings have not been saved because of the errors.'));
    }

    // $form['#submit'][] = 'power_reviews_settings_form_submit';.
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $power_reviews_field_names = json_decode($this->config('power_reviews.settings')->get('power_reviews_default_fields'), TRUE);

    foreach ($form_state->getValue('power_reviews_applied_content_types') as $content_type => $value) {
      power_reviews_update_fields($content_type, $value, $power_reviews_field_names, $form_state->getValue('power_reviews_feedless_implementation'), $form_state->getValue('power_reviews_type_of_implementation'));
    }

    $form_state->cleanValues();

    foreach ($values as $key => $value) {
      if (is_array($value) && NULL !== $form_state->getValue('array_filter')) {
        $value = array_keys(array_filter($value));
      }
      $this->configFactory()->getEditable('power_reviews.settings')
        ->set($key, $value)
        ->save();
    }

    $this->messenger()->addStatus($this->t('The configuration options have been saved.'));
  }

  /**
   * Helper function to fetch the options list of webform.
   *
   * @return array
   *   Returns options list.
   */
  protected function getNodeTypes() {
    $node_option = [];
    $node_types = NodeType::loadMultiple();

    foreach ($node_types as $key => $value) {
      $node_option[$key] = $value->get('type');
    }

    return $node_option;
  }

}

==> power_reviews-8.x-2.0.tar.gz: power_reviews/src/Form/PowerReviewsConfigureForm.php <==
<?php

namespace Drupal\power_reviews\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
Use Drupal\node\Entity\NodeType;

/**
 * Building Power Reviews config form.
 */
class PowerReviewsConfigureForm extends ConfigFormBase {

  /**
   * Node Types Array.
   *
   * @var array
   */
  private $nodeTypes;

  /**
   * Constructs a PowerReviewsConfigureForm object.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
    $this->nodeTypes = $this->getNodeTypes();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'power_reviews_configure_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['power_reviews.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('power_reviews.settings');

    $form['powerreviews_fieldset'] = [
      '#type' => 'fieldset',
      '#title' => 'Power Review API Details',
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];

    $form['powerreviews_fieldset']['power_reviews_api_key'] = [
      '#type' => 'textfield',
      '#title' => 'API Key',
      '#required' => TRUE,
      '#default_value' => $config->get('power_reviews_api_key'),
    ];

    $form['powerreviews_fieldset']['power_reviews_merchant_group_id'] = [
      '#type' => 'textfield',
      '#title' => 'Merchant Group ID',
      '#required' => TRUE,
      '#default_value' => $config->get('power_reviews_merchant_group_id'),
    ];

    $form['powerreviews_fieldset']['power_reviews_merchant_id'] = [
      '#type' => 'textfield',
      '#title' => 'Merchant ID',
      '#required' => TRUE,
      '#default_value' => $config->get('power_reviews_merchant_id'),
    ];

    $form['powerreviews_fieldset']['power_reviews_locale'] = [
      '#type' => 'textfield',
      '#title' => 'Locale',
      '#required' => TRUE,
      '#default_value' => $config->get('power_reviews_locale'),
    ];

    $form['powerreviews_fieldset']['power_reviews_feedless_implementation'] = [
      '#type' => 'radios',
      '#title' => 'Is this a feedless implementation?',
      '#required' => TRUE,
      '#options' => [
        'yes' => 'Yes',
        'no' => 'No',
      ],
      '#default_value' => $config->get('power_reviews_feedless_implementation'),
    ];

    $form['powerreviews_fieldset']['power_reviews_type_of_implementation'] = [
      '#type' => 'radios',
      '#title' => 'Type of implementation',
      '#required' => TRUE,
      '#options' => [
        'page_path' => 'Path based',
        'content_type' => 'Content type based',
      ],
      '#default_value' => $config->get('power_reviews_type_of_implementation'),
    ];

    $form['powerreviews_options_fieldset'] = [
      '#type' => 'fieldset',
      '#title' => 'Power Reviews Options',
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];

    $form['powerreviews_options_fieldset']['power_reviews_page_path'] = [
      '#type' => 'textfield',
      '#title' => 'Page path',
      '#description' => $this->t('Add page path on which power reviews should appear.'),
      '#default_value' => $config->get('power_reviews_page_path'),
      '#states' => [
        'visible' => [
          ':input[name="power_reviews_type_of_implementation"]' => ['value' => 'page_path'],
        ],
      ],
    ];

    $form['powerreviews_options_fieldset']['power_reviews_page_id'] = [
      '#type' => 'textfield',
      '#title' => 'Review page id',
      '#description' => $this->t('Add power reviews page id.'),
      '#default_value' => $config->get('power_reviews_page_id'),
      '#states' => [
        'visible' => [
          ':input[name="power_reviews_type_of_implementation"]' => ['value' => 'page_path'],
        ],
      ],
    ];

    $form['powerreviews_options_fieldset']['power_reviews_applied_content_types'] = [
      '#type' => 'checkboxes',
      '#title' => 'Content type select',
      '#description' => $this->t('Select content types on which power reviews should appear.'),
      '#options' => $this->nodeTypes,
      '#default_value' => $config->get('power_reviews_applied_content_types'),
    ];

    $form['powerreviews_options_fieldset']['power_reviews_applied_reviewsnippet'] = [
      '#type' => 'textfield',
      '#title' => 'Review snippet',
      '#description' => $this->t('Add div ID where review snippet should appear.'),
      '#default_value' => $config->get('power_reviews_applied_reviewsnippet'),
    ];

    $form['powerreviews_options_fieldset']['power_reviews_applied_reviewdisplay'] = [
      '#type' => 'textfield',
      '#title' => 'Review display',
      '#description' => $this->t('Add div ID where review display should appear.'),
      '#default_value' => $config->get('power_reviews_applied_reviewdisplay'),
    ];

    $form['powerreviews_options_fieldset']['power_reviews_custom_header'] = [
      '#type' => 'textarea',
      '#title' => 'Custom header',
      '#description' => $this->t('Enter header to be displayed above reviews.'),
      '#default_value' => $config->get('power_reviews_custom_header'),
    ];

    $form['powerreviews_options_fieldset']['power_reviews_applied_categorysnippet'] = [
      '#type' => 'textfield',
      '#title' => 'Category snippet',
      '#description' => $this->t('Add div ID where review star summary should appear.'),
      '#default_value' => $config->get('power_reviews_applied_categorysnippet'),
      '#states' => [
        'invisible' => [
          ':input[name="power_reviews_type_of_implementation"]' => ['value' => 'page_path'],
        ],
      ],
    ];

    $form['powerreviews_options_fieldset']['power_reviews_category_pages'] = [
      '#type' => 'textarea',
      '#title' => 'Category pages',
      '#description' => $this->t('Specify pages by using their paths on which category snippet should appear. Enter one path per line with leading slash.'),
      '#default_value' => $config->get('power_reviews_category_pages'),
      '#states' => [
        'invisible' => [
          ':input[name="power_reviews_type_of_implementation"]' => ['value' => 'page_path'],
        ],
      ],
    ];

    $form['powerreviews_review_fieldset'] = [
      '#type' => 'fieldset',
      '#title' => 'Write a Review Page',
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_link'] = [
      '#type' => 'textfield',
      '#title' => 'Path to write a review page',
      '#description' => $this->t('Genreates the Review Form page.'),
      '#default_value' => $config->get('power_reviews_write_review_link'),
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_page_title'] = [
      '#type' => 'textfield',
      '#title' => 'Title for write a review page',
      '#description' => $this->t('Title for the review form page.'),
      '#default_value' => $config->get('power_reviews_write_review_page_title'),
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review'] = [
      '#type' => 'textfield',
      '#title' => 'Write a review',
      '#description' => $this->t('Add div ID to show the review form.'),
      '#default_value' => $config->get('power_reviews_write_review'),
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_custom_header'] = [
      '#type' => 'radios',
      '#title' => 'Do you want a custom header?',
      '#description' => $this->t('This header will appear on top section of Write a review page.'),
      '#options' => [
        'yes' => 'Yes',
        'no' => 'No',
      ],
      '#default_value' => $config->get('power_reviews_write_review_custom_header'),
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_custom_header_title'] = [
      '#type' => 'textfield',
      '#title' => 'Header title',
      '#description' => $this->t('Enter title for header.'),
      '#default_value' => $config->get('power_reviews_write_review_custom_header_title'),
      '#states' => [
        'visible' => [
          ':input[name="power_reviews_write_review_custom_header"]' => ['value' => 'yes'],
        ],
      ],
    ];

    $form['powerreviews_review_fieldset']['power_reviews_write_review_custom_header_body'] = [
      '#type' => 'textarea',
      '#title' => 'Header body',
      '#description' => $this->t('Enter body for header.'),
      '#default_value' => $config->get('power_reviews_write_review_custom_header_body'),
      '#states' => [
        'visible' => [
          ':input[name="power_reviews_write_review_custom_header"]' => ['value' => 'yes'],
        ],
      ],
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = ['#type' => 'submit', '#value' => 'Save configuration'];

    if (!empty($_POST) && $form_state->getErrors()) {
      $this->messenger()->addError($this->t('The settings have not been saved because of the errors.'));
    }

    // $form['#submit'][] = 'power_reviews_settings_form_submit';.
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $power_reviews_field_names = json_decode($this->config('power_reviews.settings')->get('power_reviews_default_fields'), TRUE);

    foreach ($form_state->getValue('power_reviews_applied_content_types') as $content_type => $value) {
      power_reviews_update_fields($content_type, $value, $power_reviews_field_names, $form_state->getValue('power_reviews_feedless_implementation'), $form_state->getValue('power_reviews_type_of_implementation'));
    }

    $form_state->cleanValues();

    foreach ($values as $key => $value) {
      if (is_array($value) && NULL !== $form_state->getValue('array_filter')) {
        $value = array_keys(array_filter($value));
      }
      $this->configFactory()->getEditable('power_reviews.settings')
        ->set($key, $value)
        ->save();
    }

    $this->messenger()->addStatus($this->t('The configuration options have been saved.'));
  }

  /**
   * Helper function to fetch the options list of webform.
   *
   * @return array
   *   Returns options list.
   */
  protected function getNodeTypes() {
    $node_option = [];
    $node_types = NodeType::loadMultiple();

    foreach ($node_types as $key => $value) {
      $node_option[$key] = $value->get('type');
    }

    return $node_option;
  }

}
